=======
Authors
=======

Development Lead
----------------

* Martin Roberge <mroberge@towson.edu>

Contributors
------------

* Joseph Hughes <jdhughes@usgs.gov>
* Molly Pickel <mpicke8@students.towson.edu>
* Nathan Korinek <Nathan.Korinek@colorado.edu>
* Ibrahim El Merehbi <https://github.com/elmerehbi>
